# Encon
Encon is a sustainability consultancy that supports companies in various sectors, including hospitality, healthcare, retail, logistics, real estate, construction materials, food, consumer goods, and municipalities, to achieve sustainable growth. They offer creative and innovative solutions, integrating sustainability into business operations, communication, innovation, and asset management. Their services range from initial compliance and cost reduction to comprehensive strategy development, brand enhancement, and market differentiation. Encon aims to improve sustainability through new business models, mobility policies, daily habits, and optimized workplaces that minimize environmental impact and improve employee well-being. They focus on energy efficiency and renewable energy to reduce costs, meet transparency demands, and leverage sustainability for innovation and competitive advantage.

Encon's approach includes assessing current activities, building tailored teams, challenging stakeholders, negotiating quality guarantees, and acting as a central contact point for reporting and project delivery, employing audits to map the current state and formulate action plans. They also assist in subsidy program development to incentivize sustainable practices. Partnering with Encon can lead to new revenue streams, stronger brand recognition, reduced costs through efficient processes and waste reduction, and long-term compliance. Encon emphasizes a tailored approach, recognizing that sustainability solutions must be customized to each company's unique circumstances. They leverage ISO 26000 to provide concrete guidance for social responsibility and align with the United Nations Sustainability Development Goals.

Their clients include Ovidias, Volvo Trucks Gent, Ebema, Facil, Die Keure, Nelissen Steenfabrieken, Etivoet, LCP, Tribeca, Niko, Aldi, Stay, Barry Callebaut, BMW, Reynaers, Heylen Warehouses, Diresco, Luminus, EOC Group, KBC, Lanaken, Logodental, Tectum Group, Ter Beke, and Greenyard. Case studies include Volvo Trucks Gent (charging infrastructure for electric vehicles), "Lanaken, the green example" (creating a municipal plan with subsidies for energy scans of businesses), Diresco (renewable energy), EOC Group (ENO campaign), LCP (sustainable building), Tribeca (sustainable office building), Barry Callebaut (sustainable technical installations), Ghelamco (sustainable building with added value), Aldi (sustainable logistics building), Logodental (air quality), and Lotto Arena (LED installation). A key case study, "Lanaken, het groene voorbeeld", shows how Encon develops municipal sustainability strategies and subsidy programs through energy scans and savings plans to reduce energy consumption and CO2 emissions.

AI could assist Encon by enabling predictive energy consumption modeling, optimized charging scheduling for electric vehicles, infrastructure planning for charging points, and real-time energy management. AI could also automate energy scan analysis, provide personalized sustainability recommendations, optimize subsidy programs, and offer predictive modeling for municipalities. This can be incorporated into their existing energy scan process, which identifies energy consumption patterns and potential savings, to develop and implement energy-saving projects.

Encon offers an academy and welcomes visitors to their living lab, Infinity. They can be reached at +32 (0)89 410 820 or info@encon.eu, and have a presence on LinkedIn and Youtube. Encon is currently devising a digitalization strategy, which presents an opportunity for AI-driven solutions to enhance their services. Key website sections include "Duurzame Bedrijfsvoering" (Sustainable Business Operations), "Duurzame Communicatie" (Sustainable Communication), "Duurzame Innovatie" (Sustainable Innovation), and "Duurzaam Asset Management" (Sustainable Asset Management), each potentially benefiting from AI applications. They also highlight their calculation of direct growth (€277,000,000), trees spared (197,000 ha), and CO2 saved (2,363,500 tons) as a result of their work, providing quantifiable metrics where AI-driven improvements can be showcased. In 2020 Robin Bruninx was awarded CSR ambassador of the year.


## Encon's Case Studies and Service Analysis


Encon is a sustainability consultancy assisting clients in achieving sustainability goals and certifications for real estate projects. A key area of expertise lies in aiding companies like Ghelamco to obtain BREEAM, WELL, EDGE, and DGNB certifications by coordinating the certification process, performing building analyses, acting as reviewers, and modeling projects in relevant applications, leading to reduced workloads, cost savings, and increased property value. Encon supports Real Estate & Fund Management partner Tribeca in making its real estate portfolio more sustainable, from obtaining BREEAM certificates to conducting feasibility studies and collecting data, as well as assisting clients like Diresco in becoming CO2-neutral by 2030 and Barry Callebaut in making their Belgian sites more sustainable since 2019. They also helped Logistics Capital Partners (LCP) by integrating sustainability not only as an addition, but as a core value that distinguishes your projects.

AI could augment Encon's services through: automating certification document generation from building plans and data, AI-powered building analysis to optimize energy efficiency and indoor air quality, predictive modeling for certification likelihood, real-time optimization of building operations, AI-driven material selection based on sustainability, and automated regulatory compliance monitoring. Encon emphasizes that BREEAM should not be seen as a goal in itself, but as a way to achieve sustainable ambitions.


## Encon's website and information retrieval
Encon supports companies in achieving sustainability by offering creative and innovative solutions, embedding sustainability as a core business strategy, and using ISO 26000 for implementation, focusing on sustainable business operations, communication, innovation (across diverse sectors), and asset management (including technical installations, renewable energy, buildings, and human capital). Contact them at T: +32 (0)89 410 820 or E: info@encon.eu, and find them on LinkedIn and YouTube.

Recent news articles on Encon's website showcase their involvement in various sustainability aspects, suggesting opportunities to integrate AI for enhanced services. These articles (from late January to early March 2025) cover topics such as innovative software for sustainability analysis, sustainable real estate solutions at MIPIM 2025, energy savings for SMEs, wind energy opportunities in Flanders, circular real estate, EU-Taxonomy and circularity, new building heating regulations, critique of CSRD, and repowering green power installations.

Analyzing these articles reveals potential AI applications, including AI-powered data analysis and reporting for sustainability, building energy management systems, predictive maintenance and design optimization for real estate, AI-driven energy audits and personalized recommendations for SMEs, optimized wind farm operations, material lifecycle tracking for circular construction, compliance monitoring for EU-Taxonomy, regulatory change tracking, CSRD data validation, and performance monitoring for green energy installations.

Encon's "Onze klanten" page emphasizes their role as partners guiding companies toward sustainable transformation, presenting case studies that offer insights into specific client problems where AI solutions could be applied. These case studies include: Ghelamco (sustainable building and certifications like BREEAM, WELL, EDGE, and DGNB for "The Wings" project, focusing on less work, streamlined admin, costsavings), Tribeca (sustainable, future-proof office buildings), LCP (increased real estate value through eco-friendly choices), Belorta (sustainability from field to table), Etivoet (sustainable efforts), Nelissen Steenfabrieken (sustainability in brick production), Facil (CO2 reduction and relighting, and another project focusing on sustainability), Niko (improved solar panel output), Diresco (renewable energy), EOC Group (energy-saving measures). Ghelamco sought guidance in certifying 'The Wings', focusing on WELL (Gold rating, one of the first in Belgium), DGNB (Gold rating, first in Belgium), BREEAM (aiming for Excellent), and EDGE (first EDGE Advanced office building in Belgium) certifications. Encon provided support by coordinating the certification process, performing building analyses, and acting as the main contact point between Ghelamco, SGS-Sintali, and IFC. This collaboration resulted in reduced workload, cost savings, and expert guidance.

Based on this information, key questions for an exploratory call with Encon include:

1. "We noticed you're exploring innovative software for sustainability analysis. Are you currently using any AI-powered tools, and if so, in which areas?"
2. "Given your focus on sustainable real estate, how do you see AI contributing to building energy management, predictive maintenance, and optimized building design?"
3. "With the increasing importance of energy efficiency for SMEs, how can AI help in conducting energy audits and providing personalized recommendations for energy savings?"
4. "In the context of wind energy, what opportunities do you see for AI in optimizing energy production and grid integration?"
5. "How can AI facilitate material lifecycle tracking and optimization for circular construction in the real estate sector?"
6. "Considering the complexities of EU-Taxonomy and other regulations, how can AI assist in compliance monitoring and reporting?"
7. "We saw your opinion piece about CSRD. How do you think AI could address the shortcomings of current CSRD reporting practices?"
8. "What role do you see AI playing in the repowering and performance optimization of existing green energy installations?"
9. "We are experts in building AI agents that can automate tasks, extract data and make predictions. Would that be interesting for you?"


# Concluding remarks